#
# spec file for package python-swiftclient
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-swiftclient
Version:        3.5.0
Release:        lp151.2.4
Summary:        OpenStack Object Storage API Client Library
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://launchpad.net/python-swiftclient
Source0:        https://files.pythonhosted.org/packages/source/p/python-swiftclient/python-swiftclient-3.5.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python-devel
BuildRequires:  python2-keystoneclient >= 3.8.0
BuildRequires:  python2-mock >= 2.0.0
BuildRequires:  python2-pbr >= 2.0.0
BuildRequires:  python2-setuptools >= 16.0
BuildRequires:  python2-testrepository >= 0.0.18
BuildRequires:  python2-testscenarios >= 0.4
BuildRequires:  python3-devel
BuildRequires:  python3-keystoneclient >= 3.8.0
BuildRequires:  python3-mock >= 2.0.0
BuildRequires:  python3-pbr >= 2.0.0
BuildRequires:  python3-setuptools >= 16.0
BuildRequires:  python3-testrepository >= 0.0.18
BuildRequires:  python3-testscenarios >= 0.4
Requires:       python-requests >= 2.14.2
Requires:       python-six >= 1.10.0
BuildArch:      noarch
%ifpython2
Requires:       python-futures >= 3.0.0
%endif
%if 0%{?suse_version}
Requires(post): update-alternatives
Requires(postun): update-alternatives
%else
# on RDO, update-alternatives is in chkconfig
Requires(post): chkconfig
Requires(postun): chkconfig
%endif
%python_subpackages

%description
This is a python client for the Swift API. There's a Python API (the
swiftclient module), and a command-line script (swift).

%package -n python-swiftclient-doc
Summary:        %{summary} - Documentation
Group:          Documentation/HTML
BuildRequires:  python-Sphinx
BuildRequires:  python-futures >= 3.0.0
BuildRequires:  python-oslosphinx >= 4.7.0
Requires:       %{name} = %{version}

%description -n python-swiftclient-doc
This is a python client for the Swift API. There's a Python API (the
swiftclient module), and a command-line script (swift).

This package contains documentation files for %{name}.

%prep
%autosetup -p1 -n python-swiftclient-3.5.0
%py_req_cleanup

%build
%{python_build}
%{__python2} setup.py build_sphinx
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%{python_install}
%python_clone -a %{buildroot}%{_bindir}/swift
%python_clone -a %{buildroot}%{_mandir}/man1/swift.1

%post
%{python_install_alternative swift swift.1}

%postun
%python_uninstall_alternative swift

%check
%{python_expand rm -rf .testrepository
$python setup.py testr
}

%files %{python_files}
%license LICENSE
%doc ChangeLog README.rst
%{python_sitelib}/swiftclient
%{python_sitelib}/*.egg-info
%python_alternative %{_bindir}/swift
%python_alternative %{_mandir}/man1/swift.1

%files -n python-swiftclient-doc
%license LICENSE
%doc doc/build/html

%changelog
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Mon Feb 12 2018 cloud-devel@suse.de
- update to version 3.5.0 (bsc#1078607)
  - Add support for versionless endpoints
  - Update tox_install.sh to align for sphinx jobs
  - Remove setting of version/release from releasenotes
  - authors/changelog updates for 3.5.0 release
  - Allow for object uploads > 5GB from stdin.
  - Trying out the new releasenotes jobs
  - Make tox runnable in a directory with spaces
  - Add pypy-devel for RPM-based systems
  - Add releasenotes tox env
  - Revert "Add Constraints support"
  - Allow --meta on upload
* Fri Jan 19 2018 tbechtold@suse.com
- Convert to singlespec
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 3.4.0
  - ISO 8601 timestamps for tempurl
  - Fix MockHttpResponse to be more like the Real
  - merged openstack-manuals content with existing content
  - Buffer reads from disk
  - Option to ignore mtime metadata entry.
  - Allow for uploads from standard input.
  - Optimize the link address
  - Fix some reST field lists in docstrings
  - Change swift.o.o URL
  - Update the documentation link for doc migration
  - Fix logging of the gzipped body
  - moved cli doc to the right place for new links process
  - Don't recommend to overwrite imported `session` variable
  - Do not set Content-Type to '' with new requests.
  - Close file handle after upload job
  - Tolerate RFC-compliant ETags
  - respect bulk delete page size and fix logic error
  - Stop sending X-Static-Large-Object headers
  - [trivial] Be consistent in using example.com
  - Removing duplicated doc from client-api
  - Skip checksum validation on partial downloads
  - 3.4.0 authors/changelog update
  - Expose --prefix as an option for st_delete
* Mon Feb 13 2017 cloud-devel@suse.de
- update to version 3.3.0:
  - Remove redundant space in docstring
  - Update help text around container ACL syntax
  - remove swiftclient/openstack/common/* in the .coveragerc
  - prefix-based tempurls support
  - Adding keystoneauth sessions support
  - Fix typo in shell.py
  - Add v1password keystoneauth plugin
  - TrivialFix: Removed redundant 'the'
  - Add Constraints support
  - Replace 'assertEqual(None, ...)' with 'assertIsNone(...)'
  - Show team and repo badges on README
  - modify 'swift <sub_command> —help' display
  - Installs futures only for python 2.7 and 2.6
  - Fix intermittent test failure
  - Make object option dependent on container in usage strings
  - Fixed inconsistent positional arguments naming
  - Replace assertTrue(a in b) with assertIn(a, b)
  - Correct the example keystone session code imports
  - Change Examples from headings to topics
  - Typo fix
  - 3.3.0 authors/changelog update
  - Use ConfigParser instead of SafeConfigParser
  - Fix 'url' to 'URL'
  - Accept more types of input for headers/meta
  - Make tempurl subcommand insist on whole number seconds
  - add pypy to the bindep "test" profile
  - Require newer version of oslosphinx
  - Make tempurl command check for valid object path
  - Add commands examples for copy and delete
  - Enable code coverage report in console output
  - Low-level API: Don't log just before raising an exception
  - Make options arguments truely optional
  - Add additional headers for HEAD/GET/DELETE requests.
  - 3.2.0 release notes
  - Make functests py3-compatible
  - Fix order of arguments in assertIs
* Mon Sep 26 2016 tbechtold@suse.com
  update to version 3.1.0
  * Include response headers in ClientExceptions
  * Add copy object method
  * Support client certificate/key
  * Add new doc structure and contents for swiftclient
  * Add --json option to `swift capabilities` / `swift info`
  * Convert numeric and boolean header values to strings
  * Correct doc string for http_conn argument
  * authors/changelog updates for 3.1.0 release
  * Add tests for thread option validation
  * Drop *.dbm* before running tests
  * fixing nit picks in python-swiftclient doc
  * boolean logic cleanup in service.Swift[Copy|Post]Object
  * Query string functionality for containers
  * Check responses when retrying bodies
  * Add python version constraint python>=2.7
  * Use mock patch to handle get_auth_keystone
  * Default to v3 auth if we find a (user|project)-domain-(name|id) option
  * Initialise delete_object mock before it's called
  * Accept gzip-encoded API responses
  * Use application/directory content-type for dir markers
  * Fix examples and missing code-block
  * Strip leading/trailing whitespace from headers
  * Move other-requirements.txt to bindep.txt
  * Suppress InsecureRequestWarning when using --insecure
  * reenable sidebar links
  * Migrated contributing file from .md to .rst
  * Fixed a typo in SwiftService API doc
  * Move python-keystoneclient to "extras"
  * Pull option processing out to service.py
  * Add swift tempurl and swift auth command docstring
  * Add other-requirements.txt
  * Identify segments uploaded via swiftclient
  * Port from optparse to argparse
  * Fix SwiftPostObject options usage in SwiftService
  * client: renew token on 401 even if retries is 0
  * Fix downloading from "marker" item
  * Tighten up testing for sloppy auth version
  * Removes redundant "to"
  * Fix unicode issues in tempurl command
  * Parse options to dict
  * Modify assert
  * Update the home-page with developer documentation
  * Initialize delete_object mock *before* creating all the threads
  * Clean up some unnecessary variables
  * Add __ne__ built-in function
  * Add an option: disable etag check on downloads
  * Check threads number options validation
* Mon Aug  1 2016 tbechtold@suse.com
- update _service and switch to upstream spec file
* Mon Mar 14 2016 tbechtold@suse.com
- update to 3.0.0:
  * Python 2.6 and Python 3.3 support has been removed. Currently
    supported and tested versions of Python are Python 2.7 and Python 3.4.
  * Do not reveal sensitive headers in swiftclient log messages by default.
    This is controlled by the client.logger_settings dictionary. Setting the
    `redact_sensitive_headers` key to False prevents the information hiding. If
    the value is True (the default), the `reveal_sensitive_prefix` controls
    the maximum length of any sensitive header value logged. The default is
    16 to match the default in Swift.
  * Object downloads that fail partway through will now retry with a Range
    request to read the rest of the object.
  * Object uploads will be retried if the source supports seek/tell or has a
    reset() method.
  * Delete requests will use the cluster's bulk delete feature, if available,
    for requests that would require a lot of individual deletes.
  * The delete CLI option now accepts a --prefix option to delete objects that
    start with the given prefix (similar to the same-named option for list).
  * Add support for the auth-version to be specified using
  - -os-identity-api-version or OS_IDENTITY_API_VERSION
    for compatibility with other openstack client command
    line options.
  * --debug and --info command-line options now work anywhere in the command.
  * Objects can now be uploaded to pseudo-directories with the CLI.
  * Fixed an issue with uploading a large object that includes a unicode path.
  * swiftclient can now auth against Keystone using only a project (tenant)
    and a token. This is useful when the client doesn't have access to the
    password for a user but otherwise has been granted access.
  * Various other minor bug fixes and improvements.
  * This is the very last release to support Python 2.6. Any further
    development on the 2.7.x release series will only be for security bugfixes.
  * Added content type to CLI object list long-form output
  * client.get_container() and client.head_object now accept a headers parameter
  * Fixed bug when setting Content-Type on upload from CLI
  * Fixed bug when deleting DLOs with unicode characters
  * Updated man pages and docstrings
  * Suppress iso8601 logging in --debug output
  * Various other minor bug fixes and improvements.
* Mon Sep 14 2015 tbechtold@suse.com
- update to 2.6.0:
  * Several CLI options have learned short options. The usage strings have
    been updated to reflect this.
  * Added --no-shuffle option to the CLI download command.
  * Added --absolute option for CLI TempURL generation and the corresponding
    parameter to utils.generate_temp_url(). This allows for an exact, specific
    time to be used for the TempURL expiry time.
  * CLI arguments are now always decoded as UTF-8.
  * Stop Connection class modifying os_options parameter.
  * Reduce memory usage for download/delete.
  * The swift service API now logs and reports the traceback
    on failed operations.
  * Increase httplib._MAXHEADERS to 256 to work around header limits in recent
    Python releases.
  * Added minimal working service token support to client.py.
  * Various other minor bug fixes and improvements.
  * The CLI learned an "auth" subcommand which returns bash environment
    snippets for auth credentials.
  * The CLI --version option is now more explicit by calling itself
    "python-swiftclient" rather than the name of the binary.
  * Now validates the checksum of each chunk of a large object as it is
    uploaded.
  * Fixes uploading an object with a relative path.
  * Added the ability to download objects to a particular folder.
  * Now correctly removes all old segments of an object when replacing a
    Dynamic Large Object (DLO).
  * The --skip-identical option now works properly when downloading
    large objects.
  * The client.get_object() response learned a .read([length]) method.
  * Fixed an issue where an intermediate caching/proxy service could cause
    object content to be improperly decoded.
  * Added a timeout parameter to HTTPConnection objects for socket-level
    read timeouts.
  * Removed a dependency on simplejson.
  * Various other minor bug fixes and improvements.
- Adjust Requires according to requirements.txt
- Add python_requires to _service file
* Fri Apr 24 2015 tbechtold@suse.com
- Use %%{version} in source
* Thu Apr 23 2015 tbechtold@suse.com
- Switch to version 2.4.0
* Wed Apr  1 2015 cloud-devel@suse.de
- Update to version python-swiftclient-2.4.0.post2:
  2.4.0
  * Include unsupported url scheme with ClientException
* Sat Mar  7 2015 cloud-devel@suse.de
- Update to version python-swiftclient-2.3.1.post60:
  * Mention --segment-size option after 413 response
* Fri Mar  6 2015 cloud-devel@suse.de
- Update to version python-swiftclient-2.3.1.post59:
  * Add improvements to MD5 validation
  * Unindent a chunk of st_list
* Thu Feb 26 2015 cloud-devel@suse.de
- Update to version python-swiftclient-2.3.1.post56:
  * Release connection after consuming the content
  * Fix crash when stat'ing objects with non-ascii names
* Wed Feb 25 2015 cloud-devel@suse.de
- Update to version python-swiftclient-2.3.1.post52:
  * Verify MD5 of uploaded objects
  * Fix crash with -l, -d /, and pseudo folders
* Thu Feb 19 2015 cloud-devel@suse.de
- Update to version python-swiftclient-2.3.1.post48:
  * add functional tox target
* Wed Feb 11 2015 dmueller@suse.com
- add dependency on python-setuptools (bnc#914910)
* Wed Feb 11 2015 cloud-devel@suse.de
- Update to version python-swiftclient-2.3.1.post47:
  * Add help message for "<subcommand> --help"
  * Fix missing ca-certificate parameter to get_auth
* Sat Feb  7 2015 cloud-devel@suse.de
- Update to version python-swiftclient-2.3.1.post44:
  * Fix deleting SLO segments on overwrite
* Wed Feb  4 2015 cloud-devel@suse.de
- Update to version python-swiftclient-2.3.1.post43:
  * This patch fixes downloading files to stdout
* Tue Feb  3 2015 cloud-devel@suse.de
- Update to version python-swiftclient-2.3.1.post41:
  * Fix cross account upload using --os-storage-url
* Fri Jan 30 2015 cloud-devel@suse.de
- Update to version python-swiftclient-2.3.1.post39:
  * Fix environment sanitization for TestServiceUtils
* Sun Jan 11 2015 cloud-devel@suse.de
- Update to version python-swiftclient-2.3.1.post38:
  * Change tests to use CaptureOutput class
  * Check that content_type header exists before using
* Tue Jan  6 2015 cloud-devel@suse.de
- Update to version python-swiftclient-2.3.1.post35:
  * Print info message about incorrect --totals usage when neither -l nor --lh is provided. Added test coverage for --totals
* Mon Jan  5 2015 cloud-devel@suse.de
- Update to version python-swiftclient-2.3.1.post34:
  * Fix misplaced check for None in SwiftUploadObject
* Sat Jan  3 2015 cloud-devel@suse.de
- Update to version python-swiftclient-2.3.1.post32:
  * Suppress 'No handlers...' message from keystoneclient logger
* Wed Dec 31 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.3.1.post30:
  * Make preauth params work
  * Change tests to use new CaptureOutput class
* Tue Dec 16 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.3.1.26.gd59af8c:
  * Fix misnamed dictionary key
  * Show warning when auth_version >= 2 and keystoneclient is missing
* Sat Dec  6 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.3.1.22.g79fb531:
  * Workflow documentation is now in infra-manual
* Tue Dec  2 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.3.1.21.gd89e08f:
  * Capture test output better
* Thu Nov 20 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.3.1.20.gcfbabe7:
  * Add unit tests for _encode_meta_headers
  * Fix misnamed variable in SwiftReader
* Fri Nov 14 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.3.1.17.g202bbab:
  * Make swift post output an error message when failing
  * Fix KeyError raised from client Connection
* Fri Oct 31 2014 dmueller@suse.com
- rename rpmlintrc to python-swiftclient-rpmlintrc
* Wed Oct 29 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.3.1.13.g19b427e:
  * Adds user friendly message when --segment-size is a non-integer
* Mon Oct 27 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.3.1.11.g025da14:
  * Replaces Stacktraces with useful error messages
  * Fix race in shell when testing for errors to raise SysExit
  * Fix race between container create jobs during upload
  * Fix the info command with --insecure
  * Allow segment size to be specified in a human readable way
* Tue Oct 21 2014 dmueller@suse.com
- add rpmlintrc as a source
* Fri Oct 10 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.3.1.4.g83ca0b8:
  * Use skipTest from testtools instead of inherited Exception
* Wed Oct  8 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.3.1.2.gc37cecb:
  * Add tests for account listing using --lh switch
* Wed Oct  1 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.3.1.1.g21fb6f6:
  * Do not crash with "swift list --lh" for Ceph RadosGW
  2.3.1
* Sat Sep 27 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.3.0.8.gbb4d2ab:
  * Remove a debugging print statement
  * Fix unit tests failing when OS_ env vars are set
* Fri Sep 26 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.3.0.4.gd721871:
  * Fix bug with some OS options not being passed to client
  * Add per policy container count to account stat output
* Fri Sep 19 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.3.0.1.g8f1b394:
  * Stop creating extraneous directories
  2.3.0
* Wed Sep 17 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.2.0.15.g45465c7:
  * Work toward Python 3.4 support and testing
* Thu Aug 28 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.2.0.14.gd13441d:
  * Adds console script entry point
* Wed Aug 27 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.2.0.12.g24673f8:
  * Add importable SwiftService incorporating shell.py logic
* Thu Aug 21 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.2.0.11.gd97ec37:
  * fixed unit tests when env vars are set
* Thu Aug 21 2014 tbechtold@suse.com
- Update to version python-swiftclient-2.2.0.9.g309437b:
  * Do not create an empty directory 'pseudo/'
  * Fix crash when downloading a pseudo-directory
  * Clean up raw policy stats in account stat
  * Update theme for docs
  * Add keystone v3 auth support
- Add python-oslosphinx as BuildRequires
* Wed Jul 30 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.2.0.1.gfd15949:
  * Add a tox job for generating docs
  2.2.0
* Wed Jul 23 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.1.0.22.g394cb57:
  * Fix context sensitive help for info and tempurl
* Tue Jul 22 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.1.0.21.gf9ea672:
  * Allow to specify storage policy when uploading objects
* Sat Jul 19 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.1.0.19.g4cc2201:
  * Adding Swift Temporary URL support
* Sat Jul 12 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.1.0.17.gd5a45fc:
  * replace string format arguments with function parameters
* Thu Jul 10 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.1.0.15.g74f921f:
  * Add context sensitive help
* Wed Jul  9 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.1.0.13.gc8ad38d:
  * Relax requirement for tenant_name in get_auth()
  * Removed now unnecesary workaround for PyPy
* Sat Jul  5 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.1.0.11.g061607f:
  * Add CONTRIBUTING.md
* Fri Jun 27 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.1.0.10.g916f5cb:
  * Relax requirement for tenant_name in get_auth(
* Thu May 29 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.1.0.9.g3d0de79:
  * change assertEquals to assertEqual
* Wed May 28 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.1.0.7.ga030734:
  * Use Emacs-friendly coding line
* Tue May 27 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.1.0.6.gb4d9707:
  * Remove extra double quote from docstring
* Sun May 25 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.1.0.5.g1d81933:
  * fixed several pep8 issues
  * Remove testtools.main() call from tests
* Sat May 24 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.1.0.1.geaf4fcb:
  * Fix wrong assertions in unit tests
  2.1.0
* Fri May 23 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.0.3.91.g258420f:
  * Fix Python3 bugs
* Wed May 21 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.0.3.90.ge7dc854:
  * Move test_shell.py under tests/unit/
* Sat May 17 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.0.3.89.g761ba37:
  * Mark swiftclient as being a universal wheel
  * change assert_ to assertTrue
  * fixed typos found by RETF rules
* Thu May 15 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.0.3.83.g1270cb2:
  * Provide a link to the documentation to the README
  * Declare that we support Python 3
* Tue May 13 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.0.3.79.g22badfd:
  * Fix running the unittests under py3
  * Add "." for help strings
* Thu May  8 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.0.3.76.g3895d85:
  * Make the function tests Python3-import friendly
  * Only encode metadata for user customed headers
* Tue May  6 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.0.3.73.g4e85183:
  * Add functional tests for python-swiftclient
* Wed Apr 30 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.0.3.71.gb1ca705:
  * Mock auth_end_time in test_shell.test_download
* Sat Apr 26 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.0.3.69.g9ff3bad:
  * Removed a duplicate word in a dostring
  * Don't utf8 encode urls
* Fri Apr 25 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.0.3.67.g37bf0ff:
  * Fixed several shell tests on Python3
  * Fix up StringIO use in tests for py3
* Thu Apr 24 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.0.3.63.gfc66708:
  * Updated test_shell for Python3
  * Fix test_raw_upload test
  * Remove validate_headers
  * Use quote/unquote from six module for py3
* Sat Apr 19 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.0.3.55.gcda2573:
  * Add tests for bin/swift
* Fri Apr 18 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.0.3.53.gfa20e7f:
  * Makes use of requests.Session
* Thu Apr 17 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.0.3.52.gaaa563c:
  * Fix test_multithreading on Python 3
  * Fix swiftclient.client.quote() for Python 3
* Tue Apr 15 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.0.3.48.gec538d3:
  * Add requests related unit-tests
* Fri Apr 11 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.0.3.46.gcdd8d33:
  * Python 3: fix tests on HTTP headers
* Tue Apr  8 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.0.3.44.ge04bf9e:
  * Make bin/swift testable part 2
* Sun Apr  6 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.0.3.42.gc5cc2b7:
  * Update help message to specify unit of --segment-size option
  * Use the standard library's copy of mock when it's available
* Fri Apr  4 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.0.3.39.gfa65fbb:
  * Updated from global requirements
* Thu Apr  3 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.0.3.38.g132c643:
  * Removed usage of tuple unpacking in parameters
* Wed Apr  2 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.0.3.36.ge0fa104:
  * Replaced print statements with print function
  * don't use mutable defaults in kwargs
  * set user-agent header
  * Decode HTTP responses, fixes bug #1282861
* Tue Apr  1 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.0.3.28.g21db1bf:
  * Python 3: Get compatible types from six
  * Python 3: Fix module names in import
* Sat Mar 29 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.0.3.25.gcdf6f84:
  * Python 3: Add six dependency
  * Replace dict.iteritems() with dict.items()
  * Python 3: Replace iter.next() with six.next(iter)
  * Python 3: Fix tests using temporary text files
  * Python 3: cast map() result to list
* Thu Mar 27 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.0.3.16.g100419c:
  * Make bin/swift testable part 1
* Sat Mar 22 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.0.3.15.g070dd48:
  * Fix temporary pypy gate issue with setuptools
  * Copy Swift's .mailmap to swiftclient repo
* Fri Mar 21 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.0.3.11.g8ff7d56:
  * Use six.StringIO instead of StringIO.StringIO
* Sat Mar 15 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.0.3.9.gd721dc7:
  * Improve help strings
* Wed Mar 12 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.0.3.7.g41f5763:
  * TCP port is appended two time in ClientException
* Mon Mar 10 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.0.3.5.g07dd668:
  * add "info" as an alias to "capabilities"
* Thu Mar  6 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.0.3.4.gd2f3563:
  2.0.3
  * Help string format persistent
  * Make the help strings constant
* Sat Mar  1 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.0.2.14.g52893e3:
  * Add LengthWrapper in put_object to honor content_length param
  * Updated from global requirements
  * swift.1 manpage fix for groff warnings
* Thu Feb 20 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.0.2.8.gf4e0579:
  * Remove useless statement
* Wed Feb 19 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.0.2.6.g21cec82:
  2.0.2
  * Only run flake8 on swiftclient code
  * Add option to skip downloading/uploading identical files
  * Add missing backslash
* Sun Feb 16 2014 cloud-devel@suse.de
- Update to version python-swiftclient-2.0.1.1.g380e830:
  * Remove multipart/form-data file upload
  2.0.1
* Fri Feb 14 2014 dmueller@suse.com
- Update to version python-swiftclient-2.0.1.g79f189a:
  * Fix --insecure option on auth
  * Remove extraneous vim configuration comments
  * Rename Openstack to OpenStack
  * Port to python-requests
* Tue Feb 11 2014 speilicke@suse.com
- Update to version python-swiftclient-1.8.0.52.gf13288a:
  * Remove tox locale overrides
  * Fix swiftclient help
  * Fix misspellings in python swiftclient
  * changed things because reasons
  * match hacking rules in swift
  * Updated from global requirements
  * Install manpage in share/man/man1 instead of man/man1
  * assertEquals is deprecated, use assertEqual
- Replace git_tarballs source service with download_files and set_version
  + Use upstream URL as source (enables verification)
* Wed Feb  5 2014 speilicke@suse.com
- Fix manpage install
* Sat Feb  1 2014 opensuse-cloud@opensuse.org
- Update to version 1.8.0.47:
  + Add capabilities option
  + Updated from global requirements
  + assertEquals is deprecated, use assertEqual
  + Install manpage in share/man/man1 instead of man/man1
* Sun Jan 26 2014 opensuse-cloud@opensuse.org
- Update to version 1.8.0.39:
  + match hacking rules in swift
* Mon Jan 20 2014 dmueller@suse.com
- Update to version 1.8.0.38:
  + Install swiftclient manpage
  + Replace xrange in for loop with range
  + retry on ratelimit
- add 0001-Install-manpage-in-share-man-man1-instead-of-man-man.patch
* Mon Jan 20 2014 dmueller@suse.com
- install manpages
* Thu Jan 16 2014 dmueller@suse.com
- fix requires
* Thu Dec 26 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.0.33:
  + Add --object-name
* Sun Dec 22 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.0.31:
  + Fix help of some optional arguments
* Tue Dec 17 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.0.29:
  + Updates tox.ini to use new features
* Sun Dec 15 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.0.27:
  + Enable usage of proxies defined in environment (http(s)_proxy).
* Fri Dec 13 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.0.25:
  + Fix Sphinx version issue
  + Fixes python-swiftclient debugging message
* Tue Dec 10 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.0.22:
  + Skip sniffing and reseting if retry is disabled
* Sun Dec  8 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.0.20:
  + Don't crash when header is value of None
* Wed Dec  4 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.0.18:
  + Fix download bandwidth for swift command.
* Sat Nov 30 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.0.16:
  + Updates .gitignore
  + Add close to swiftclient.client.Connection
* Thu Nov 28 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.0.13:
  + Allow custom headers when using swift download (CLI)
* Mon Nov 25 2013 dmueller@suse.com
- switch to python-setuptools
* Fri Nov 22 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.0.11:
  + Add verbose output to all stat commands
* Sat Nov  2 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.0.9:
  + Replaced two references to Cloud Files with Swift
* Sun Oct 27 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.0.8:
  + Fix a typo in help text: "downlad"
* Sat Oct 19 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.0.7:
  + enhance swiftclient logging
* Thu Oct 17 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.0.5:
  + user defined headers added to swift post queries
  + Extend usage message for `swift download`
* Mon Oct 14 2013 opensuse-cloud@opensuse.org
- Update to version 1.8.0.1:
  + Clarify main help for post subcommand
* Mon Oct 14 2013 opensuse-cloud@opensuse.org
- Update to version 1.7.0.3:
  + Make pbr only a build-time dependency.
* Tue Oct  8 2013 opensuse-cloud@opensuse.org
- Update to version 1.7.0.1:
  + assertEquals is deprecated, use assertEqual (H602)
* Sun Sep 22 2013 opensuse-cloud@opensuse.org
- Update to version 1.6.0.3:
  + fix bug with replace old *LOs
* Wed Sep 18 2013 dmueller@suse.com
- fix requires
* Tue Sep 17 2013 opensuse-cloud@opensuse.org
- Update to version 1.6.0.1:
  + Sync with global requirements
* Fri Aug 30 2013 opensuse-cloud@opensuse.org
- Update to version 1.5.0.23:
  + Remove redundant unit suffix
  + Added support for running the tests under PyPy with tox
* Mon Aug 26 2013 opensuse-cloud@opensuse.org
- Update to version 1.5.0.20:
  + Add a NullHandler when setting up library logging
  + Reformat help outputs
* Sun Jul 14 2013 opensuse-cloud@opensuse.org
- Update to version 1.5.0.7:
  + Update docstring for swiftclient.Connection.__init__
* Sat Jul 13 2013 opensuse-cloud@opensuse.org
- Update to version 1.5.0.6:
  + Allow setting # of retries in the binary
  + Adds max-backoff for retries in Connection.
* Thu Jul 11 2013 opensuse-cloud@opensuse.org
- Update to version 1.5.0.2:
  + Allow storage url override for both auth vers.
* Mon Jul  8 2013 opensuse-cloud@opensuse.org
- Update to version 1.4.0.35:
  + Note '-V 2' is necessary for auth 2.0
* Fri Jul  5 2013 opensuse-cloud@opensuse.org
- Update to version 1.4.0.34:
  + Add -p option to download command.
* Wed Jun 26 2013 dmueller@suse.com
- update to master branch
- update requires
* Wed May 29 2013 dmueller@suse.com
- remove setBadness call from rpmlintrc
- fix buildrequires
* Wed May 15 2013 bwiedemann@suse.com
- upgrade to 1.4.0.7 ; BuildRequire python-pbr python-d2to1
* Mon Apr 22 2013 dmueller@suse.com
- update to 1.4.0
* Tue Apr  2 2013 dmueller@suse.com
- downgrade to released version (1.3.0)
* Wed Mar 27 2013 speilicke@suse.com
- BuildRequire python (for the ssl module)
* Mon Mar 18 2013 speilicke@suse.com
- Drop +git.$TIMESTAMP.$COMMITHASH version suffix
* Tue Mar  5 2013 cloud-devel@suse.de
- Update to version 1.3.0.10+git.1362503939.999e1c0:
  + Add client man page swift.1
  + Allow to specify segment container
  + Added "/" check when list containers.
* Fri Feb 22 2013 saschpe@suse.de
- BuildRequire openstack-suse-macros instead of openstack-macros
* Mon Feb 11 2013 cloud-devel@suse.de
- Update to version 1.3.0.5+git.1360595600.4ac431a:
  + Print useful message when keystoneclient is not installed
* Mon Feb  4 2013 dmueller@suse.com
- Update to version 1.3.0.4+git.1359979977.b5f222b:
  + Fix reporting version.
  + Use testr instead of nose.
* Wed Jan 23 2013 cloud-devel@suse.de
- Update to version 1.1.1.58+git.1358959422.bf09dd9:
  + Update to latest oslo version/setup.
* Thu Jan 17 2013 vuntz@suse.com
- Use version-regexp param for git_tarballs service to avoid
  uselessly including the last git commit id twice.
* Mon Jan 14 2013 saschpe@suse.de
- (Build)Require python-pyOpenSSL instead of M2Crypto (to get the
  ssl Python base module)
* Mon Jan 14 2013 saschpe@suse.de
- Fix requirement on python-simplejson
* Mon Jan 14 2013 cloud-devel@suse.de
- Update to version 1.2.0.30.g3d04363+git.1358165890.3d04363:
  + Add env[SWIFTCLIENT_INSECURE]
  + Fix debug feature and add --debug to swift.
  + Use testtools as base class for test cases.
  + Add --os-cacert
- Updated requirements
* Wed Dec 19 2012 saschpe@suse.de
- Update to version 1.2.0.25.g7df9cad+git.1355914385.7df9cad:
  + Add --insecure option to fix bug #1077869
  + Don't segment objects smaller than --segment-size
  + Don't add trailing slash to auth URL.
  + Adding segment size as another x-object-manifest component
  + Stop loss of precision when writing 'x-object-meta-mtime'
  + Remove unused json_request.
  + fixed inconsistencies in parameter descriptions
  + tell nose to explicity test the 'tests' directory
  + Fixes setup compatibility issue on Windows
  + Force utf-8 encode of HTTPConnection params
  + swiftclient Connection : default optional arguments to None
  + Add OpenStack trove classifier for PyPI
* Wed Dec  5 2012 saschpe@suse.de
- Use @PARENT_TAG@ in _service file to automate versioning
* Fri Nov 23 2012 saschpe@suse.de
- Add requirement on python-M2Crypto, it is needed at runtime
* Thu Nov 22 2012 saschpe@suse.de
- Add rpmlintrc
* Thu Nov 15 2012 saschpe@suse.de
- Use openstack-macros
* Thu Nov  8 2012 saschpe@suse.de
- Install LICENSING and README.rst
- Build HTML documentation and split of doc package
  + BuildRequire python-Sphinx
- BuildRequire changes:
  + python-base instead of python-devel, sufficient for Python-only modules
  + python-distribute instead of setuptools
- Drop from_vcs build flag
* Fri Oct 12 2012 vuntz@suse.com
- Update to version 2012.2 (Folsom), which is really 1.2.0:
  + See https://github.com/openstack/python-swiftclient/commits/1.2.0
* Mon Oct  1 2012 jenkins@suse.de
- Update to latest git (57dfd21):
  + Fix PEP8 issues.
  + Add ability to download without writing to disk.
  + PEP8 issues fixed
  + PEP8 cleanup.
  + Allow endpoint type to be specified.
  + Add region_name support
  + Do not use dictionaries as default parameters
  + Catch authorization failures
  + Resolves issue with empty os_options for swift-bench & swift-dispersion-report
* Mon Sep 10 2012 bwiedemann@suse.com
- include tox.ini to make tox tests run
* Tue Aug 28 2012 jenkins@suse.de
- Update to latest git (58baa42):
  + Add nosehtmloutput as a test dependency.
  + Change '_' to '-' in options
* Wed Aug 22 2012 jenkins@suse.de
- Update to latest git (46aad0e):
  + Ensure Content-Length header when PUT/POST a container
* Sat Aug 18 2012 jenkins@suse.de
- Update to latest git (6941260):
  + Add timing stats to verbose download output.
  + Shuffle download order (of containers and objects)
* Tue Aug 14 2012 jenkins@suse.de
- Update to latest git (99b8253):
  + Make python-keystoneclient optional
* Wed Aug  8 2012 jenkins@suse.de
- Update to latest git (c87458e):
  + Fix container delete throughput and 409 retries.
* Thu Aug  2 2012 jenkins@suse.de
- Update to latest git (1f6096e):
  + Use keystoneclient for authentication.
* Fri Jul 27 2012 saschpe@suse.de
- Cleanup specfile
- Add -test package requirement on python-tox
* Fri Jul 27 2012 cthiel@suse.com
- split off test subpackage
* Thu Jul 26 2012 cthiel@suse.com
- initial package
